@@ -26,11 +26,11 @@
 
 #include <config.h>
 #include <stdlib.h>
+#include <popt.h>
 
 #define GCONF_ENABLE_INTERNALS
 #include <gconf/gconf.h>
 #include <gconf/gconf-client.h>
-extern struct poptOption gconf_options[];
 
 #include "gnome-i18nP.h"
 
@@ -55,11 +55,14 @@ gnome_gconf_get_gnome_libs_settings_relative (const gchar *subkey)
 {
         gchar *dir;
         gchar *key;
+        gchar *tmp;
+
+        tmp = gconf_escape_key (gnome_program_get_app_id (gnome_program_get()), -1);
 
         dir = g_strconcat("/apps/gnome-settings/",
-                          gnome_program_get_app_id (gnome_program_get()),
+                          tmp,
                           NULL);
-
+        g_free (tmp);
         if (subkey && *subkey) {
                 key = gconf_concat_dir_and_key(dir, subkey);
                 g_free(dir);
@@ -165,7 +168,7 @@ _gnome_gconf_module_info_get (void)
 		NULL /* instance init */,
 		NULL /* pre_args_parse */,
 		NULL /* post_args_parse */,
-		gconf_options,
+		NULL /* options */,
 		NULL /* init_pass */,
 		NULL /* class_init */,
 		NULL, NULL /* expansions */
